@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2025 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 1.0.9
-;; Package-Revision: 1.0.9-0-gec339632e0fa
+;; Package-Version: 1.1.0
+;; Package-Revision: 1.1.0-0-g41f57f059bd8
 ;; URL: https://github.com/jamescherti/vim-tab-bar.el
 ;; Keywords: frames
 ;; Package-Requires: ((emacs "28.1"))
@@ -160,8 +160,6 @@ ungrouped tabs."
         (setq tab-bar-format '(tab-bar-format-tabs-groups tab-bar-separator))
       (setq tab-bar-format '(tab-bar-format-tabs tab-bar-separator)))
 
-    (setq tab-bar-show t)
-
     ;; The tab bar's appearance
     (set-face-attribute 'tab-bar frame
                         :background bg-tab-inactive
@@ -297,7 +295,9 @@ ungrouped tabs."
 
 ;;;###autoload
 (define-minor-mode vim-tab-bar-mode
-  "Toggle `vim-tab-bar-mode'."
+  "Emulate the Vim tab bar.
+This styles the tab-bar to emulate Vim's tabbed interface while maintaining
+visual consistency with the currently active theme's color scheme."
   :global t
   :lighter " VimTB"
   :group 'vim-tab-bar
